C      PROGRAM ARENS(INPUT,OUTPUT,TAPE5=INPUT,TAPE6=OUTPUT,
C     +TAPE8,TAPE9,TAPE10)
C  MAIN ROUTINE OF A PROGRAM TO ABBREVIATE YEAR-LENGTH WEATHER TAPES
C  BY SELECTING SHORT CONTIGUOUS INTERVALS OF DAYS TO REPRESENT EACH
CC                            MONTH.
C  REF: NALL,D.H.,ARENS,E.A.,"ABBREVIATION OF CLIMATE DATA....
C       ASHRAE TRANS VOL 87, PART 1, PP.923-934,1981
C
C  USE LOGICAL UNIT 8 TO INPUT FULL-YEAR WEATHER FILE IN WYEC FORMAT.
C  USE LOGICAL UNIT 9 TO WRITE SHORT-YEAR WEATHER FILE.
C  USE LOGICAL UNIT 10 TO WRITE SHORT-YEAR WITH PRECONDITIONING
C
C
C  THE INTERVALS ARE PRINTED FOR EVALUATION ACCORDING TO THREE
C  TYPES OF RANKING SYSTEMS: 
C         TYPE0 RANKS INTERVALS BASED ON THEIR DRY BULB
C              AVERAGE TEMPERATURE ALONE.
C         TYPE1 RANKS INTERVALS BASED ONTHE REGRESSION
C              FORMULA.
C         TYPE2 RANKS INTERVALS BASED ON THE FORMULA
C              ADJUSTED FOR INTERVAL TOTAL DRY BULB
C              TEMPERATURE RANGE.
C  THE SHORT-YEAR FILE IS CREATED FROM TYPE2 ONLY IN THIS PROGRAM.
C
C
C
C  VARIABLES IN ORDER OF LISTING: 
C
C
C  DLTADB:  DIFFERENCE IN DRY BULB AVERAGE TEMPERATURE BETWEEN INTERVAL
C         AND MONTH, F.
C  DLTADR:  DIFFERENCE IN DRY BULB RANGE BETWEEN INTERVAL AND MONTH, F..
C  WSDBSP:  AVERAGE WINDSPEED-TEMPERATURE-PRODUCT OF INTERVAL, F X MPH.
C  CCSPAN:  AVERAGE CLOUD COVER FOR INTERVAL, TENTHS,
C  DBSPAN:  AVERAGE DRY BULB TEMPERATURE FOR INTERVAL, F.
C  SRANGE:  DRY BULB TEMPERATURE RANGE OF INTERVAL, F.
C  NDAY:    NUMBER OF DAYS IN MONTH.
C  DAVG:    DAILY AVERAGE DRY BULB TEMPERATURE, F.
C  DR:      DAILY DRY BULB TEMPERATURE RANGE, F.
C  TMAX:    MONTHLY MAXIMUM DRY BULB TEMPERATURE, F.
C  TMIN:    MONTHLY MINIMUM DRY BULB TEMPERATURE, F.
C  CLOUD:   DAILY CLOUD COVER. TENTHS.
C  DBMAX:   DAILY MAXIMUM DRY BULB TEMPERATURE, F.
C  DBMIN:   DAILY MINIMUM DRY BULB TEMPERATURE, F.
C  WSDBY:   DAILY WINDSPEED-DRY-BULB-TEMPERATURE-PRODUCT, F X MPH.
C  WAY:     SUM OF HOURLY MOISTURE RATIOS FOR DAY, LB H2O VAPOR PER
C           LB DRY AIR.
C  RANK1:   RANK OF INTERVAL ACCORDING TO FORMULA.
C  RANK2:   RANK ACCORDING TO GREATEST TEMPERATURE RANGE.
C  CCADY:   DAILY AVERAGE CLOUD COVER DURING SUNLIT HOURS, TENTHS.
C  CCADSP:  AVERAGE SUNLIT CLOUD COVER FOR INTERVAL, TENTHS.
C  DLCCAD:  DIFFERENCE IN SUNLIT CLOUD COVER FOR INTERVAL AND MONTH,
C           TENTHS.
C  DLWSDB:  DIFFERENCE IN WINDSPEED-TEMPERATURE-PRODUCT FOR INTERVAL,
C           F X MPH.
C  WASP:    AVERAGE OF DAILY MOISTURE-RATIO-SUMS FOR INTERVAL, LB H2O
C           VAPOR PER LB DRY AIR.
C  DLWA:    DIFFERENCE IN MOISTURE-RATIO-SUM-AVERAGES BETWEEN INTERVAL
C           AND MONTH, LB H2O VAPOR PER LB DRY AIR.
C  RANK0:   INTERVAL RANK ACCORDING TO DRY BULB TEMPERATURE.
C  SCALE0:  NORMALIZED RANK ACCORDING TO DRY BULB TEMPERATURE.
C  SCALE1:  NORMALIZED RANK ACCORDING TO FORMULA.
C  SCALE2:  NORMALIZED RANK ACCORDING TO TOTAL TEMPERATURE RANGE.
C  INTVAL:  ORDER OF INTERVALS IN MONTH FROM SUBROUTINE ORDER.
C  I0:      ORDER OF INTERVALS IN MONTH FOR DRY BULB TEMPERATURE.
C  I1:      ORDER OF INTERVALS IN MONTH ACCORDING TO FORMULA.
C  I2:      ORDER OF INTERVALS IN MONTH ACCORDING TO TOTAL RANGE.
C  DB2AVM:  INPUT DRY BULB AVERAGE FOR BIASING SECTION FROM LONG-
C           TERM MONTHLY AVERAGES, F.
C  DP2AV7:  INPUT DEWPOINT AVERAGE FOR BIASING SELECTION FROM LONG-
C           TERM MONTHLY AVERAGES, F.
C  CCAD2M:  INPUT SUNLIT CLOUD COVER AVERAGE FOR BIASING SECTION FROM
C           LONG-TERM MONTHLY AVERAGES, TENTHS.
C  WSAVM:   INPUT WINDSPEED AVERAGE FOR BIASING SELECTION FROM LONG-
C           TERM MONTHLY AVERAGES, MPH.
C  PBT2M:   INPUT BAROMETRIC PRESSURE AVERAGE FOR BIASING SELECTION
C           FROM LONG-TERM MONTHLY AVERAGES, IN. HG.
C  ISELCT:  BEST INTERVAL FOR MONTH.
C  WA2M:    CALCULATED MOISTURE-RATIO-SUM FOR BIASING SELECTION FROM
C           MONTHLY AVERAGES, LB H2O VAPOR PER LB DRY AIR.
C  DRSPAN:  AVERAGE DAILY RANGE FOR INTERVAL, F.
C  NUMDAY:  NUMBER OF DAYS IN YEAR.
C  IINT:    LENGTH OF INTERVAL IN DAYS.
C  MONTH:   NUMBER OF MONTH.
C  IDAY:    DAY OF MONTH.
C  AVG:     DRY BULB TEMPERATURE AVERAGE, F.
C  DAYMAX:  DAILY MAXIMUM TEMPERATURE, F.
C  DAYMIN:  DAILY MINIMUM TEMPERATURE, F.
C  CC:      CLOUD COVER, TENTHS.
C  CCAD:    SUNLIT CLOUD CLOUD COVER, THETHS.
C  WA:      MOISTURE-RATIO-SUM. LB H2O PER LB DRY AIR.
C  WSDB:  WINDSPEED DRY-BULB-TEMPERATURE-PRODUCT, F X MPH.
C  ILONG: SWITCH FOR AVERAGE CHANGING MODE.
C  CLAVGM:     AVERAGE CLOUDINESS FOR MOTNH, TENTHS.
C  DBAVGM:  AVERAGE DRY BULB TEMPERATURE FOR MONTH, F.
C  DRAVGM:  AVERAGE DAILY RANGE FOR MONTH, F.
C  CCADM:   AVERAGE SUNLIT CLOUD OVER FOR MONTH, TENTHS.
C  WSDBM:   AVERAGE WIND-SPEED-TEMPERATURE-PRODUCT FOR MONTH, F X MPH.
C WAM:      AVERAGE MOISTURE-RATIO-SUM FOR MONTH, LB H2O VAPOR PER LB
C           DRY AIR.
C  A2ED:    SAVING VARIABLE FOR DBAVGM.
C  A3ED:    SAVING VARIABLE FOR CCADM.
C  A4ED:    SAVING VARIABLE FOR WSDBM.
C  ASED:    SAVING VARIABLE FOR WAM.
C  NSPAN:   NUMBER OF INTERVALS IN MONTH.
C  DBX:     SUMMING VARIABLE FOR INTERVAL DRY BULB TEMPERATURE.
C  DRX:     SUMMING VARIABLE FOR INTERVAL DAILY RANGE.
C  CCX:     SUMMING VARIABLE FOR INTERVAL CLOUD COVER.
C  CCADX:   SUMMING VARIABLE FOR INTERVAL SUNLIT CLOUD COVER.
C  WSDBX:   SUMMING VARIABLE FOR INTERVAL WIND-SPEED-TEMPERATURE-PRODUCT
C  WAX:     SUMMING VARIABLE FOR INTERVAL MOISTURE-RATIO-SUM.
C  SPMAX:   INTERVAL MAXIMUM TEMPERATURE.
C  SPMIN:   INTERVAL MINIMUM TEMPERATURE.
C  FACTOS:  NORMALIZING VARIABLE FOR TEMPERATURE SCORE.
C  FACTOR:  NORMALIZING VARIABLE FOR FORMULA SCORE.
C  FACTOR2:  NORMALIZING VARIABLE FOR TOTAL RANGE SCORE.
C  ISFIL:  SWITCH FOR MAKING SHORT TAPE.
      DIMENSION DLTADB(28),DLTADR(28),WSDBSP(28),DBSPAN(28),CCSPAN(28),
     + SRANGE(28),NDAY(12),DAVG(12,31),DR(12,31),TMAX(12),TMIN(12),
     + CLOUD(12,31),DBMAX(12,31),DBMIN(12,31),WSDBY(12,31),WAY(12,31),
     + RANK1(28),RANK2(28),CCADY(12,31),CCADSP(28),DLCCAD(28),DLWSDB(28)
     + ,WASP(28),DLWA(28),RANK0(28),SCALE0(28),SCALE1(28),SCALE2(28),
     + INTVAL(28),I0(28),I1(28),I2(28),DB2AVM(12),DP2AVM(12),CCAD2M(12),
     + WSAVM(12),PBT2M(12),ISELCT(12),WA2M(12),DRSPAN(28)
      COMMON/BLK2/NDAYS(12),NCTY
      OPEN(8,FILE='TAPE8',STATUS='OLD',IOSTAT=IO8)
      IF(IO8.NE.0)THEN
        WRITE(6,*)' CANT OPEN TAPE8 WEATHER TAPE FILE'
        STOP ' CANT OPEN TAPE8 WEATHER TAPE FILE'
        ENDIF
      OPEN(5,FILE='ARENS.DAT',STATUS='OLD',IOSTAT=IO5)
      IF(IO5.NE.0)THEN
        WRITE(6,*)' CANT OPEN ARENS.DAT INPUT DATA FILE'
        STOP ' CANT OPEN ARENS.DAT INPUT DATA FILE'
        ENDIF
      OPEN(9,FILE='TAPE9',STATUS='NEW',IOSTAT=IO9)
      IF(IO9.NE.0)THEN
        WRITE(6,*)' DELETE TAPE9 AND TRY AGAIN!'
        STOP ' DELETE TAPE9 AND TRY AGAIN!'
        ENDIF
      OPEN(10,FILE='TAPE10',STATUS='NEW',IOSTAT=IO10)
      IF(IO10.NE.0)THEN
        WRITE(6,*)' DELETE TAPE10 AND TRY AGAIN'
        STOP ' DELETE TAPE10 AND TRY AGAIN'
        ENDIF
      OPEN(6,FILE='TAPE6',STATUS='NEW',IOSTAT=IO6)
      IF(IO6.NE.0)THEN
        WRITE(6,*)' DELETE TAPE6 AND TRY AGAIN'
        STOP ' DELETE TAPE6 AND TRY AGAIN'
        ENDIF
C  NCTY  (1-29)  ASSUMES WYEC TAPE ATTACHED AS TAPE8
    1 READ(5,*,END=999)NCTY,IPRE,ISL
      GO TO 2
  999 STOP 'ENDED WITH EOF ON TAPE5, OKAY?'
    2 IF(ISL.LE.0)GO TO 7
C
C GET SELECTED DATA
      READ(5,*)IINT
      READ(5,*)ISELCT
      GO TO 172
    7 DO 8 I=1,12
    8 ISELCT(I)=0
      REWIND 8
      CALL SKPCTY
      READ(5,*)MONTHI,IDAYI,MONTHF,IDAYF,IINT
      DO 9 MONTH=MONTHI,MONTHF
      NDAYI=IDAYI
      IF(MONTH.NE.MONTHI)NDAYI=1
      NDAYF=IDAYF
      IF(MONTH.NE.MONTHF)NDAYF=NDAYS(MONTH)
      DO 9 IDAY=NDAYI,NDAYF
        CALL DAY (MONTH,IDAY,AVG,DAYMAX,DAYMIN,CC,CCAD,WA,WSDB)
        DBMAX(MONTH,IDAY)=DAYMAX
        DBMIN(MONTH,IDAY)=DAYMIN
        DAVG(MONTH,IDAY)=AVG
        DR(MONTH,IDAY)=DAYMAX-DAYMIN
        CLOUD(MONTH,IDAY)=CC
        CCADY(MONTH,IDAY)=CCAD
        WSDBY(MONTH,IDAY)=WSDB
        WAY(MONTH,IDAY)=WA
        IF (IDAY.EQ.1) TMAX(MONTH)=DAYMAX
        IF (IDAY.EQ.1) TMIN(MONTH)=DAYMIN
        TMAX(MONTH)=AMAX1(DAYMAX,TMAX(MONTH))
        TMIN(MONTH)=AMIN1(DAYMIN,TMIN(MONTH))
9       NDAY(MONTH)=IDAY
      READ (5,*) ILONG
      IF (ILONG.NE.1) GO TO 15
      WRITE(6,130)
      WRITE(6,140)
      WRITE(6,135)
      DO 10 MONTH=1,12
        READ (5,*) DB2AVM(MONTH),CCAD2M(MONTH),WSAVM(MONTH),DP2AVM
     +  (MONTH),PBT2M(MONTH)
        CALL PSY6 (DB2AVM(MONTH),DP2AVM(MONTH),PBT2M(MONTH),WA2M(MONTH))
10      CONTINUE
15    CONTINUE
      MONTH=MONTHI-1
   16 MONTH=MONTH+1
      IF(MONTH.GT.MONTHF)GO TO 155
        CLAVGM=0.
        DBAVGM=0.
        DRAVGM=0.
        CCADM=0.
        WSDBM=0.
        WAM=0.
        L=NDAY(MONTH)
        DO 20 I=1,L
          DBAVGM=DBAVGM+DAVG(MONTH,I)
          DRAVGM=DRAVGM+DR(MONTH,I)
          CCADM=CCADM+CCADY(MONTH,I)
          WSDBM=WSDBM+WSDBY(MONTH,I)
          WAM=WAM+WAY(MONTH,I)
20        CLAVGM=CLAVGM+CLOUD(MONTH,I)
        DBAVGM=DBAVGM/L
        DRAVGM=DRAVGM/L
        ABSDRM=TMAX(MONTH)-TMIN(MONTH)
        CLAVGM=CLAVGM/L
        CCADM=CCADM/L
        WSDBM=WSDBM/L
        WAM=WAM/L
        A2ED=DBAVGM
        A3ED=CCADM
        A4ED=WSDBM
        A5ED=WAM
        IF (ILONG.NE.1) GO TO 25
        DBAVGM=DB2AVM(MONTH)
        CCADM=CCAD2M(MONTH)
        WSDBM=WSAVM(MONTH)*(65-DBAVGM)
        WAM=WA2M(MONTH)*24.
25      CONTINUE
        WRITE(6,30)
30      FORMAT ('1',2X,'MONTH',8X,'DBAVG',15X,'WSDBT',15X,'RANGE',5X,
     +  'WAAVG',6X,'CCAD',5X,'TYPE0',5X,'TYPE1',5X,'PRINT2')
        WRITE(6,35) MONTH,DBAVGM,WSDBM,ABSDRM,WAM,CCADM
35      FORMAT (I5,'  TAPE',F9.2,10X,F10.2,10X,3F10.2)
        IF (ILONG.NE.1) WRITE(6,40)
40      FORMAT (/)
        IF (ILONG.EQ.1) WRITE(6,45) A2ED,A4ED,A5ED,A3ED
45      FORMAT (5X,' INPUT',F9.2,10X,F10.2,20X,2F10.2)
        NSPAN=NDAY(MONTH)-IINT+1
        DO 55 I=1,NSPAN
          DBX=0.
          DRX=0.
          CCX=0.
          CCADX=0.
          WSDBX=0.
          WAX=0.
          DO 50 J=1,IINT
            K=I+J-1
            DBX=DBX+DAVG(MONTH,K)
            DRX=DRX+DR(MONTH,K)
            CCX=CCX+CLOUD(MONTH,K)
            CCADX=CCADX+CCADY(MONTH,K)
            WSDBX=WSDBX+WSDBY(MONTH,K)
            WAX=WAX+WAY(MONTH,K)
            IF (J.EQ.1) SPMAX=DBMAX(MONTH,K)
            IF (J.EQ.1) SPMIN=DBMIN(MONTH,K)
            SPMAX=AMAX1(SPMAX,DBMAX(MONTH,K))
50          SPMIN=AMIN1(SPMIN,DBMIN(MONTH,K))
          DBSPAN(I)=DBX/IINT
          DRSPAN(I)=DRX/IINT
          CCSPAN(I)=CCX/IINT
          CCADSP(I)=CCADX/IINT
          WSDBSP(I)=WSDBX/IINT
          WASP(I)=WAX/4.
          SRANGE(I)=SPMAX-SPMIN
          DLTADB(I)=DBSPAN(I)-DBAVGM
          DLTADR(I)=SRANGE(I)-ABSDRM
          DLCCAD(I)=CCADSP(I)-CCADM
          DLWSDB(I)=WSDBSP(I)-WSDBM
          DLWA(I)=WASP(I)-WAM
          RANK0(I)=ABS(DLTADB(I))
          IF (I.EQ.1) FACTOS=RANK0(I)
          FACTOS=AMAX1(FACTOS,RANK0(I))
          RANK1(I)=7.53*ABS(DLTADB(I))+4.64*ABS(DLCCAD(I))+.1*ABS(DLWSDB
     +      (I))+4.5*1.06*80.*ABS(DLWA(I))
          IF (I.EQ.1) FACTOR=RANK1(I)
          FACTOR=AMAX1(FACTOR,RANK1(I))
          RANK2(I)=ABS(DLTADR(I))
          IF (I.EQ.1) FACTO2=RANK2(I)
          FACTO2=AMAX1(FACTO2,RANK2(I))
55        CONTINUE
        WRITE(6,60)
60      FORMAT (5X,'INTERVAL',11X,'DELTADB',14X,'DLTWSDB',34X,'RANK',6X,
     +  'RANK',6X,'RANK')
        DO 80 I=1,NSPAN
          SCALE0(I)=100.*(1.-RANK0(I)/FACTOS)
          SCALE1(I)=100.*(1.-RANK1(I)/FACTOR)
          IF (SCALE1(I).GT.85.) GO TO 65
          SCALE2(I)=0.
          GO TO 70
65        SCALE2(I)=100.*(1.-RANK2(I)/FACTO2)
70        CONTINUE
          WRITE(6,75) I,DBSPAN(I),DLTADB(I),WSDBSP(I),DLWSDB(I),
     +    SRANGE(I),WASP(I),CCADSP(I),SCALE0(I),SCALE1(I),SCALE2(I)
75        FORMAT (I10,11F10.2)
80        CONTINUE
        DO 85 I=1,28
85        INTVAL(I)=I
        CALL ORDER (SCALE0,INTVAL,NSPAN)
        DO 90 I=1,28
          I0(I)=INTVAL(I)
90        INTVAL(I)=I
        CALL ORDER (SCALE1,INTVAL,NSPAN)
        DO 95 I=1,28
          I1(I)=INTVAL(I)
95        INTVAL(I)=I
        CALL ORDER (SCALE2,INTVAL,NSPAN)
        DO 100 I=1,28
          I2(I)=INTVAL(I)
100       INTVAL(I)=I
        WRITE(6,115)
        DO 105 I=1,NSPAN
          J=NSPAN-I+1
105       WRITE(6,110) J,I0(I),SCALE0(I),I1(I),SCALE1(I),I2(I),SCALE2(I)
        ISELCT(MONTH)=I2(NSPAN)
        IF (SCALE2(NSPAN).EQ.0) ISELCT(MONTH)=I1(NSPAN)
        WRITE(6,170)ISELCT(MONTH)
110     FORMAT (I10,3(I10,F10.2))
115     FORMAT ('/ORDERED RANKINGS'/5X,'ORDER',3X,'INTERVAL',4X,'TYPE0',
     +  3X,'INTERVAL',4X,'TYPE1',3X,'INTERVAL',4X,'TYPE2')
125     FORMAT (' DO YOU WANT TO CHANGE AVERAGES? 1=YES, RETURN=NO ')
130     FORMAT (' SEE CLIMATIC ATLAS OF THE UNITED STATES FOR AVERAGES')
135     FORMAT (' TEMPERATURE   COVER     AVERAGE   TEMPERATURE',
     +  '   PRESSURE')
140     FORMAT ('  DRY BULB  MEAN SKY  WIND SPEED  DEW POINT  ',
     +  'BAROMETRIC')
145     FORMAT (' HOW LONG IS THIS WEATHER TAPE IN DAYS?')
150     FORMAT (' HOW MANY  DAYS IN INTERVAL FOR MONTH')
      GO TO 16
155     CONTINUE
 165  FORMAT (' DO YOU WANT TO MAKE SHORT YEAR FILE? 1=YES, RETURN=NO')
 170  FORMAT (' THE CHOSEN INTERVAL STARTS ON DAY ',I2)
  172 READ(5,*)ISFILE
      REWIND 8
      IF (ISFILE.EQ.1) THEN
          ISFILE=0
          DO 180 MONTH=1,12
          IF(ISELCT(MONTH).NE.0)THEN
                 WRITE(6,510)MONTH,ISELCT(MONTH)
                 CALL SHORTY(IINT,MONTH,ISELCT,ISFILE)
                 ENDIF
  180     CONTINUE
      ENDIF
      WRITE(6,690)ISFILE
 690  FORMAT (I2,' 1 MEANS SHORT YEAR FILE COMPLETE')
      IF(IPRE.GT.0)CALL PREC(IPRE)
      GO TO 1
  500 FORMAT(I5,5I3,I4,I1,2I2,I1,I3,I2,I1,I3,2I2,I1,I3,2I2,I1,
     +I3,I4,I10,I4,3I2,I1)
  510 FORMAT(1X,'MONTH,ISELCT= ',2I5)
      END
      SUBROUTINE SHORTY(IINT,MONTHT,ISELCT,ISFILE)
C     SUBROUTINE TO CREATE A SHORT WEATHER FILE GIVEN SELECTED INTERVALS
C
C VARIABLES: 
C NDAYS:  NUMBER OF DAYS IN EACH MONTH OF YEAR.
C MOWARM: WARM-UP MONTH NUMBER (NEEDED FOR LOADS PROGRAMS).
C ALEAP:  REAL QUOTIENT OF YEAR DIVIDED BY FOUR.
C ILEAP:  INTEGER QUOTIENT OF YEAR DIVIDED BY FOUR.
C BLEAP:  REAL NUMBER EQUL TO ILEAP.
C INDAY:  NUMBER OF DAY BEING DONE.
C N1:     FIRST DAY OF INTERVAL.
C N2:     LAST DAY OF INTERVAL.
C
      DIMENSION ISELCT(12)
      COMMON/BLK1/IA(29),ICITY,IYEAR,MONTH,IDAY,IHR,ISNOW,
     +TDB,TWB,WSPD,SOLR,BAR
      COMMON/BLK2/NDAYS(12),NCTY
      CALL SKPCTY
      WRITE(6,503)
      N1=ISELCT(MONTHT)
      IF(N1.EQ.0)RETURN
      N2=N1+IINT-1
   10 CALL IAS
      IF(MONTH.NE.MONTHT)GO TO 10
      I=0
      IF(IDAY.GE.N1.AND.IDAY.LE.N2)GO TO 30
   20 IF(IDAY.EQ.N2) RETURN
      GO TO 10
   30 I=I+1
      IF(I.EQ.25)GO TO 20
      IF(I.EQ.1)GO TO 32
      CALL IAS
   32 WRITE(6,502)ICITY,IYEAR,MONTH,IDAY,IHR,ISNOW,TDB,TWB,WSPD,SOLR
     +,BAR
      WRITE(9,501)TDB,TWB,WSPD,SOLR,BAR,MONTH,IDAY,IHR
      ISFILE=1
      GO TO 30
  501 FORMAT(1H ,2(F5.1,2X),F5.1,2X,F6.1,2X,F6.2,2X,3(I2,3X))
  502 FORMAT(1H ,I5,2X,I4,4(2X,I2),5X,5G13.5)
  503 FORMAT(1X,' STA',4X,'YR  MON DAY  HR SNOW',9X,'TDB',10X,'TWB',
     +10X,'WSPD',9X,'SOLAR',9X,'BAR')
      END
      SUBROUTINE DAY(MONTH,IDAY,AVG,DAYMAX,DAYMIN,CLOUD,CCAD,WAAVG,
     *WSAVG)
C     SUBROUTINE TO READ A TRY TAPE RECORD AND CALCULATE DAILY
C     AVERAGES FOR SOME OF THE WEATHER VARIABLES THEREIN OR CALCULATED
C     FROM THESE VARIABLES. NO INPUTS.
C
C
C OUTPUT VARIABLES: 
C MONTH:  NUMBER OF MONTH.
C IDAY:   NUMBER OF DAY OF MONTH.
C AVG:    DRY BULB AVERAGE TEMPERATURE FOR DAY.
C DAYMAX: MAXIMUM DRY BULB TEMPERATURE FOR DAY, F.
C DAYMIN: MINIMUM DRY BULB TEMPERATURE FOR DAY, F.
C CLOUD:  CLOUD COVER AVERAGE FOR DAY, TENTHS.
C CCAD:   SUNLIT CLOUD COVER AVERAGE FOR DAY, TENTHS.
C WAAVG:  MOISTURE-RATIO-SUM FOR DAY, LB H2O VAPOR PER LB DRY AIR.
C WSAVG:  WINDSPEED-DRYBULB-TEMPERATURE-PRODUCT AVERAGE FOR DAY,
C         F X MPH.
C VARIABLE: 
C DAWN:   HOUR OF DAWN IN MONTH.
C ARRAY:  ARRAY FOR ACCEPTING 'TRY' DATA.
C DB:     HOURLY DRY BULB TEMPERATURE, F.
C CC:     HOURLY CLOUD COVER, TENTHS.
C LENGTH: HOURS OF SUNLIGHT FOR DAY IN MONTH.
C DPT:    HOURLY DEW POINT TEMPERATURE, F.
C PBT:    HOURLY BAROMETRIC PRESSURE, IN. HG.
C WST:    HOURLY WIND SPEED, MPH.
C IYEAR:  YEAR OF TAPE.
C TOTAL:  DRY BULB TEMPERATURE SUMMING VARIABLE.
C TOC:    TYPE OF CLOUD.
C WA:     MOISTURE RATIO, LB H2O VAPOR PER LB DRY AIR.
      INTEGER DAWN
      DIMENSION DB(24), CC(24) ,LENGTH(12), DAWN(12),TOC(24)
     *,DPT(24),PBT(24),WST(24),IAMI(4),IT(4),ITYP(4),IA(29)
      DATA IAMI/10,13,17,21/
      DATA ITYP/11,14,18,22/
C     DAWN, LENGTH DATA IS FOR 36 DEGREES NORTH LATITUDE
      DATA DAWN/8,7,7,6,6,5,5,6,6,7,7,8/
      DATA LENGTH/7,9,9,11,11,13,13,11,11,9,9,7/
      DATA NTQ/0/
      DATA NTZ/600/
      WAAVG=0.
      WSAVG=0.
      CLOUD=0.
      TOTAL=0.
      CCAD=0.
    6 READ(8,500,END=98)IA
    7 MONTHT=IA(26)
      IDAYT=IA(27)
      NTZ=NTZ+1
      IF(NTZ.LT.500)WRITE(6,578)MONTH,MONTHT,IDAY,IDAYT
  578 FORMAT(1X,' MONTH,MONTHT,DAY,DAYT= ',4I5)
      IF(MONTHT.EQ.MONTH.AND.IDAYT.EQ.IDAY)GO TO 8
      GO TO 6
    8 J=0
    9 J=J+1
      DB(J)=FLOAT(IA(2))
      DPT(J)=FLOAT(IA(4))
      PBT(J)=FLOAT(IA(7))*.01
      IF (DPT(J)-DB(J)) 20,10,10
   10 DPT(J)=DB(J)
   20 PV=PVSF(DPT(J))
      WA=0.622*PV/(PBT(J)-PV)
      WST(J)=FLOAT(IA(6))*1.15077
      CC(J)=FLOAT(IA(9))
      DO 21 I=1,4
      IAMT=IA(IAMI(I))
      IT(I)=0
   21 IF(IAMT.NE.99)IT(I)=1
      TOCJ=0.
      INUM=0
      DO 22 I=1,4
      IF(IT(I).EQ.0)GO TO 22
      INUM=INUM+1
      TOCJ=TOCJ+IA(ITYP(I))
   22 CONTINUE
      IF(INUM.EQ.0)GO TO 23
      TOC(J)=TOCJ/INUM
      GO TO 24
   23 TOC(J)=0.
   24 TOTAL=TOTAL+DB(J)
      IF(TOC(J)) 35,30,35
   30 CC(J)=.5*CC(J)
   35 CLOUD=CLOUD+CC(J)
      WAAVG=WAAVG+WA
      WSAVG=WSAVG+WST(J)*(65-DB(J))
      IF(J.EQ.1) DAYMAX=DB(J)
      IF(J.EQ.1) DAYMIN=DB(J)
      DAYMAX=AMAX1(DAYMAX,DB(J))
      DAYMIN=AMIN1(DAYMIN,DB(J))
      IF(J.EQ.24)GO TO 40
   38 READ(8,500,END=99)IA
      GO TO 9
   40 CONTINUE
      CLOUD=CLOUD/24.
      AVG=TOTAL/24.
      WSAVG=WSAVG/24.
      I1=DAWN(MONTH)
      I2=I1+LENGTH(MONTH)
      DO 50 I=I1,I2
   50 CCAD=CCAD+CC(I)
      CCAD=CCAD/(LENGTH(MONTH)+1)
      RETURN
   98 WRITE(6,501)
      NTQ=NTQ+1
      CLOSE(8)
      OPEN(8)
      IF(NTQ.LT.200)GO TO 6
      STOP
   99 IF(MONTH.EQ.12)RETURN
      WRITE(6,502)
      NTQ=NTQ+1
      CLOSE(8)
      OPEN(8)
      IF(NTQ.LT.200)GO TO 38
      STOP
  500 FORMAT(I5,5I3,I4,I1,2I2,I1,I3,I2,I1,I3,2I2,I1,I3,2I2,I1,
     +I3,I4,10X,I4,3I2,I1)
  501 FORMAT(1H0,'EOF ON TAPE8 NEAR LABEL 5 IN SUBROUTINE DAY')
  502 FORMAT(1H0,'EOF ON TAPE8 NEAR LABEL 40 IN SUBROUTINE DAY')
      END
      SUBROUTINE ORDER(TEMP,V,N)
C     ORDERS SCORES IN INCREASING VALUE AND ORDERS ARRAY V ACCORDINGLY.
C
C INPUTS: 
C TEMP:   A SCORE TO BE ORDERED.
C V:      ARRAY CONTAINING ORDINAL POSITION (IN INCREASING ORDER)
C         OF ELEMENTS IN TEMP.
C N:      NUMBER OF ELEMENTS TO BE ORDERED.
C OUTPUTS: 
C TEMP:   ORDER OF SCORES FROM SMALLEST TO LARGEST.
C
      DIMENSION TEMP(28),V(28),AA(200),AB(200)
      DO 50 I=1,N
      BA=1499.
      DO 25 J=1,N
      IF(BA-TEMP(J)) 25,25,10
   10 K=J
      BA=TEMP(J)
   25 CONTINUE
      TEMP(K)=1500.
      AA(I)=BA
   50 AB(I)=V(K)
      DO 75 L=1,N
      TEMP(L)=AA(L)
   75 V(L)=AB(L)
      RETURN
      END
      SUBROUTINE PSY6(DB,DP,PB,W)
C PSYCHROMETRIC SUBROUTINE FOR SHORT YEAR PROGRAM
C
C INPUT VARIABLES: 
C DB:     DRY BULB TEMPERATURE, F.
C DP:     DEW POINT TEMPERATURE, F.
C PB:     BAROMETRIC PRESSURE, IN. HG.
C OUTPUT VARIABLES: 
C W:      MOISTURE RATIO, LB H20 VAPOR PER LB DRY AIR.
C PV:     PARTIAL VAPOR PRESSURE OF WATER VAPOR IN
C         MOIST AIR. IN. HG.
C
      IF(DP-DB) 20,10,10
  10  DP=DB
  20  PV=PVSF(DP)
      W=0.622*PV/(PB-PV)
      RETURN
      END
      FUNCTION PVSF(X)
C     FUNCTION PSYCHROMETRIC SUBROUTINE FOR CALCULATION OF
C     PARTIAL VAPOUR PRESSURE OF WATER AT A GIVEN TEMPERATURE
C     FOR A SATURATED CONDITION.
C
C INPUTS X, A TEMPERATURE, AND RETURNS PVSF, THE SATURATED PARTIAL VAPOR
C PRESSURE OF WATER IN MOIST AIR.
C
      DIMENSION A(6),B(4),P(4)
      DATA A /-7.90298,5.02808,-1.3816E-7,11.344,
     + 8.1328E-3,-3.49149/ ,B/-9.09718,-3.56654,0.876793,0.0060273/
      T=(X+459.688)/1.8
      IF(T.LT.273.16) GOTO 10
      Z=373.16/T
      P(1)=A(1)*(Z-1)
      P(2)=A(2)*ALOG10(Z)
      Z1=A(4)*(1-1/Z)
      P(3)=A(3)*(10**Z1-1)
      Z1=A(6)*(Z-1)
      P(4)=A(5)*(10**Z1-1)
      GOTO 20
  10  Z=273.16/T
      P(1)=B(1)*(Z-1)
      P(2)=B(2)*ALOG10(Z)
      P(3)=B(3)*(1-1/Z)
      P(4)=ALOG10(B(4))
  20  SUM=0.
      DO 30 I=1,4
   30 SUM=SUM+P(I)
      PVSF=29.921*10**SUM
      RETURN
      END
      SUBROUTINE SKPCTY
C
C  SKIP DATA FOR NCTY-1 CITIES ON WYEC TAPE
      COMMON/BLK2/NDAYS(12),NCTY
      DIMENSION IBC(9)
      IBCI=0
      NCT=0
      NTQ=0
      IF(1.GT.NCTY.OR.NCTY.GT.29)GO TO 50
      IF(NCTY.EQ.1)RETURN
      NREC=(NCTY-1)*8760
      NRC=0
    5 NRC=NRC+1
      IF(NRC.GT.NREC)RETURN
    6 READ(8,500,END=98)IBC
      IF(IBC(1).EQ.IBCI)GO TO 5
      NCT=NCT+1
      IF(NCT.GT.50)GO TO 10
      WRITE(6,503)NCT,IBC(1)
   10 IBCI=IBC(1)
      GO TO 5
   98 WRITE(6,504)
      NTQ=NTQ+1
      CLOSE(8)
      OPEN(8)
      IF(NTQ.LT.200)GO TO 6
      WRITE(6,505)
      WRITE(6,502)NCTY,NREC
      STOP
   50 WRITE(6,501)NCTY
      STOP
  500 FORMAT(A5,A5,7A10)
  501 FORMAT(1H0,'---OOPS,NCTY OUT OF RANGE OF 1-29, NCTY= ',I10)
  502 FORMAT(1H0,'---OOPS,EOF ON TAPE8 IN SUBROUTINE SKPCTY'/
     +1X,'NCTY,NREC= ',2I10)
  503 FORMAT(1X,' CITY NO= ',I5,'  CITY STA NO = ',I9)
  504 FORMAT(1X,'FOUND EOF ON TAPE8')
  505 FORMAT(1X,'TOO MANY EOFS ON TAPE8,SO STOP')
      END
      SUBROUTINE IAS
C
C  READ WYEC TAPE
      COMMON/BLK1/IA(29),ICITY,IYEAR,MONTH,IDAY,IHR,
     +ISNOW,TDB,TWB,WSPD,SOLR,BAR
      DATA NTQ/0/
    5 READ(8,500,END=98)IA
      GO TO 10
   98 WRITE(6,504)
      NTQ=NTQ+1
      CLOSE(8)
      OPEN(8)
      IF(NTQ.LT.200)GO TO 5
      WRITE(6,505)
      WRITE(6,501)
      STOP
   10 ICITY=IA(1)
      IYEAR=IA(25)
      MONTH=IA(26)
      IDAY=IA(27)
      IHR=IA(28)
      ISNOW=IA(29)
      TDB=FLOAT(IA(2))
      TWB=FLOAT(IA(3))
C  WYEC WIND SPD IS IN KNOTS,SO CONVERT TO MPH
      WSPD=FLOAT(IA(6))*1.15077
C  WYEC BAR IS IN HG X 100., SO CONVERT TO PSIA
      BAR=FLOAT(IA(7))*.004912
C  WYEC SOLAR IS IN LANGLEYS X 10.,SO CONVERT TO BTU/HR-FT2
      SOLR=FLOAT(IA(24))
      IF(SOLR.GT.9000.)SOLR=0.
      SOLR=SOLR*.3687
      RETURN
  500 FORMAT(I5,5I3,I4,I1,2I2,I1,I3,I2,I1,I3,2I2,I1,I3,2I2,I1,
     +I3,I4,10X,I4,3I2,I1)
  501 FORMAT(1H0,'---OOPS,EOF ON TAPE8 IN SUBROUTINE IAS')
  504 FORMAT(1X,'FOUND EOF ON TAPE8')
  505 FORMAT(1X,'TOO MANY EOFS ON TAPE8,SO STOP--')
      END
      SUBROUTINE PREC(IPRE)
C
C  PROVIDE IPRE DAYS OF WEATHER DATA PRECEDING
C  FIRST DAY OF DATA FROM TAPE9 ON TAPE10
      DIMENSION TDB(24),TWB(24),WSPD(24),SOLR(24),BAR(24),
     +MONTH(24),IDAY(24),IHR(24),IDAYSV(24)
      REWIND 9
      ISTP=IPRE+1
      READ(9,500)(TDB(J),TWB(J),WSPD(J),SOLR(J),BAR(J),
     +MONTH(J),IDAY(J),IHR(J),J=1,24)
      DO 2 J=1,24
    2 IDAYSV(J)=IDAY(J)
      DO 10 K=1,ISTP
      IDQ=ISTP-K
      DO 5 J=1,24
    5 IDAY(J)=IDAYSV(J)-IDQ
      BARQ=0.
      DO 7 J=1,24
      BARQ=BARQ+BAR(J)
    7 WRITE(10,500)TDB(J),TWB(J),WSPD(J),SOLR(J),BAR(J),
     +MONTH(J),IDAY(J),IHR(J)
      BARP=BARQ/24.
      WRITE(6,501)MONTH(1),IDAY(1),BARP
   10 CONTINUE
      DO 20 K=2,365
      BARQ=0.
      DO 15 J=1,24
      READ(9,500,END=99)TDB(J),TWB(J),WSPD(J),SOLR(J),
     +BAR(J),MONTH(J),IDAY(J),IHR(J)
   15 BARQ=BARQ+BAR(J)
      BARP=BARQ/24.
      WRITE(6,501)MONTH(1),IDAY(1),BARP
      WRITE(10,500)(TDB(J),TWB(J),WSPD(J),SOLR(J),BAR(J),
     +MONTH(J),IDAY(J),IHR(J),J=1,24)
   20 CONTINUE
   99 RETURN
  500 FORMAT((1X,2(F5.1,2X),F5.1,2X,F6.1,2X,F6.2,2X,3(I2,3X)))
  501 FORMAT(1X,' MONTH,DAY,MEAN BAR(PSIA)= ',2I5,2X,F6.2)
      END
      BLOCK DATA
      COMMON/BLK2/NDAYS(12),NCTY
      DATA NDAYS/31,28,31,30,31,30,31,31,30,31,30,31/
      END
